require 'spec_helper'

describe RailsNavigation::Matcher do

  describe 'with a controller' do
    it 'matches a controller' do
      condition = 'pages'
      controller_name, action_name, params = 'pages', 'edit', {}
      result = RailsNavigation::Matcher.match_single?(controller_name, action_name, params, condition)
      expect(result).to be_truthy
    end
  end

  describe 'with a controller and action' do
    it 'matches a controller with action' do
      condition = 'pages#edit'
      controller_name, action_name, params = 'pages', 'edit', {}
      result = RailsNavigation::Matcher.match_single?(controller_name, action_name, params, condition)
      expect(result).to be_truthy
    end

    it 'does not match a controller with a wrong action' do
      condition = 'pages#show'
      controller_name, action_name, params = 'pages', 'edit', {}
      result = RailsNavigation::Matcher.match_single?(controller_name, action_name, params, condition)
      expect(result).to be_falsey
    end
  end

  describe 'with controller, action and a single parameter' do
    it 'matches a controller, action and param id as default' do
      condition = 'pages#edit?about'
      controller_name, action_name, params = 'pages', 'edit', { id: 'about' }
      result = RailsNavigation::Matcher.match_single?(controller_name, action_name, params, condition)
      expect(result).to be_truthy
    end

    it 'does not match a controller, action and param id as default' do
      condition = 'pages#edit?about'
      controller_name, action_name, params = 'pages', 'edit', { id: 'imprint' }
      result = RailsNavigation::Matcher.match_single?(controller_name, action_name, params, condition)
      expect(result).to be_falsy
    end

    it 'matches a controller, action and param' do
      condition = 'pages#edit?from=homepage'
      controller_name, action_name, params = 'pages', 'edit', { from: 'homepage' }
      result = RailsNavigation::Matcher.match_single?(controller_name, action_name, params, condition)
      expect(result).to be_truthy
    end

    it 'does not match a wrong controller, action and param' do
      condition = 'pages#edit?from=start'
      controller_name, action_name, params = 'pages', 'edit', { from: 'homepage' }
      result = RailsNavigation::Matcher.match_single?(controller_name, action_name, params, condition)
      expect(result).to be_falsy
    end
  end

  describe 'with array of conditions' do
    it 'matches one of multiple conditions' do
      conditions = ['pages#edit', 'recipes#show']
      controller_name, action_name, params = 'pages', 'edit', { }
      result = RailsNavigation::Matcher.match_multiple_with_or?(controller_name, action_name, params, conditions)
      expect(result).to be_truthy
      controller_name, action_name, params = 'recipes', 'show', { }
      result = RailsNavigation::Matcher.match_multiple_with_or?(controller_name, action_name, params, conditions)
      expect(result).to be_truthy
      controller_name, action_name, params = 'books', 'index', { }
      result = RailsNavigation::Matcher.match_multiple_with_or?(controller_name, action_name, params, conditions)
      expect(result).to be_falsey
    end
  end
end